@@ -1,5 +1,8 @@
 package org.gcube.portlets.user.td.widgetcommonevent.shared.tr.column;
 
+import java.util.Arrays;
+import java.util.List;
+
 /**
  * 
  * @author "Giancarlo Panichi" <a
@@ -24,10 +27,15 @@ public enum ColumnDataType {
 		return id;
 	}
 
-	public String getColumnDataTypeLabel() {
+	public String getLabel() {
 		return id;
 	}
 	
+	public String getId(){
+		return id;
+	}
+	
+	
 	/**
 	 * 
 	 * @param id
@@ -43,5 +51,11 @@ public enum ColumnDataType {
 		}
 		return null;
 	}
+	
+	public static List<ColumnDataType> asList() {
+		List<ColumnDataType> list=Arrays.asList(values());
+		return list;
+	}
+	
 
 }
